"""LightGBM estimator subpackage.

Re-exports for backward compatibility:
    ``from lizyml.estimators.lgbm import LGBMAdapter``
"""

from lizyml.estimators.lgbm.adapter import LGBMAdapter

__all__ = [
    "LGBMAdapter",
]
